==> antos0.47.tar.gz: antos0.47/sys/syscall.h <==
/*
 * sys/syscall.h
 */


#ifndef share_syscall_h
#define share_syscall_h


/* ƥॳֹ档 */
#define	SYS_OPEN			0
#define	SYS_EXEC			1
#define	SYS_READ			2
#define	SYS_WRITE			3
#define	SYS_CLOSE			4
#define	SYS_LSEEK			5
#define	SYS_MKDIR			6
#define	SYS_RENAME			7
#define	SYS_UNLINK			8
#define	SYS_RMDIR			9
#define	SYS_OPENDIR			10
#define	SYS_READDIR			11
#define	SYS_REWINDDIR		12
#define	SYS_CHDIR			13
#define	SYS_FCHDIR			14
#define	SYS_GETCWD			15
#define	SYS_LOCK			16
#define	SYS_MOUNT			17
#define	SYS_UMOUNT			18
#define	SYS_FORK			19
#define	SYS_EXIT			20
#define	SYS_SLEEP			21
#define	SYS_ALARM			22
#define	SYS_TIME			23
#define	SYS_GETTIMEOFDAY	24
#define	SYS_SYNC			25
#define	SYS_WAIT			26
#define	SYS_GETPID			27
#define	SYS_GETGID          28
#define	SYS_GETPGID         29
#define	SYS_GETPPID         30
#define	SYS_GETUID          31
#define	SYS_GETSID          32
#define	SYS_SETGID          33
#define	SYS_SETPGID         34
#define	SYS_SETUID			35
#define	SYS_SETSID			36
#define	SYS_TIMES			37
#define	SYS_SIGACTION		38
#define	SYS_SIGPROCMASK		39
#define	SYS_KILL			40
#define	SYS_SIGPENDING		41
#define	SYS_SIGSUSPEND		42
#define	SYS_STAT			43
#define	SYS_FCNTL			44
#define	SYS_CHATTR			45
#define	SYS_FCHATTR			46
#define	SYS_BRK				47
#define	SYS_REBOOT			48
#define	SYS_IOCTL			49
#define	SYS_LINK			50
#define	SYS_SYMLINK			51
#define	SYS_READLINK		52
#define	SYS_SELECT			53
#define	SYS_POLL			54
#define	SYS_GETFSSTAT		55
#define	SYS_STATFS			56
#define	SYS_UNAME			57
#define	SYS_TTYNAME			58
#define	SYS_SETTIME			59
#define	SYS_SOCKET			60
#define	SYS_SEND			61
#define	SYS_RECV			62
#define	SYS_CONNECT			63
#define	SYS_SHUTDOWN		64
#define	SYS_BIND			65
#define	SYS_LISTEN			66
#define	SYS_ACCEPT			67
#define	SYS_GETSOCKNAME		68
#define	SYS_GETPEERNAME		69
#define	SYS_GETSOCKOPT		70
#define	SYS_SETSOCKOPT		71
#define	SYS_SENDMSG			72
#define	SYS_RECVMSG			73
#define	SYS_GETITIMER		74
#define	SYS_SETITIMER		75
#define	SYS_TEST			76
#define	SYS_ENTRYS			77		/* ƥॳ륨ȥ꡼ */


#endif

==> antos0.49.tar.gz: antos0.49/sys/syscall.h <==
/*
 * sys/syscall.h
 */


#ifndef share_syscall_h
#define share_syscall_h


/* ƥॳֹ档 */
#define	SYS_OPEN			0
#define	SYS_EXEC			1
#define	SYS_READ			2
#define	SYS_WRITE			3
#define	SYS_CLOSE			4
#define	SYS_LSEEK			5
#define	SYS_MKDIR			6
#define	SYS_RENAME			7
#define	SYS_UNLINK			8
#define	SYS_RMDIR			9
#define	SYS_OPENDIR			10
#define	SYS_READDIR			11
#define	SYS_REWINDDIR		12
#define	SYS_CHDIR			13
#define	SYS_FCHDIR			14
#define	SYS_GETCWD			15
#define	SYS_LOCK			16
#define	SYS_MOUNT			17
#define	SYS_UMOUNT			18
#define	SYS_FORK			19
#define	SYS_EXIT			20
#define	SYS_SLEEP			21
#define	SYS_ALARM			22
#define	SYS_TIME			23
#define	SYS_GETTIMEOFDAY	24
#define	SYS_SYNC			25
#define	SYS_WAIT			26
#define	SYS_GETPID			27
#define	SYS_GETGID          28
#define	SYS_GETPGID         29
#define	SYS_GETPPID         30
#define	SYS_GETUID          31
#define	SYS_GETSID          32
#define	SYS_SETGID          33
#define	SYS_SETPGID         34
#define	SYS_SETUID			35
#define	SYS_SETSID			36
#define	SYS_TIMES			37
#define	SYS_SIGACTION		38
#define	SYS_SIGPROCMASK		39
#define	SYS_KILL			40
#define	SYS_SIGPENDING		41
#define	SYS_SIGSUSPEND		42
#define	SYS_STAT			43
#define	SYS_FSTAT			44
#define	SYS_LSTAT			45
#define	SYS_FCNTL			46
#define	SYS_BRK				47
#define	SYS_REBOOT			48
#define	SYS_IOCTL			49
#define	SYS_LINK			50
#define	SYS_SYMLINK			51
#define	SYS_READLINK		52
#define	SYS_SELECT			53
#define	SYS_POLL			54
#define	SYS_GETFSSTAT		55
#define	SYS_STATFS			56
#define	SYS_UNAME			57
#define	SYS_TTYNAME			58
#define	SYS_SETTIME			59
#define	SYS_SOCKET			60
#define	SYS_SEND			61
#define	SYS_RECV			62
#define	SYS_CONNECT			63
#define	SYS_SHUTDOWN		64
#define	SYS_BIND			65
#define	SYS_LISTEN			66
#define	SYS_ACCEPT			67
#define	SYS_GETSOCKNAME		68
#define	SYS_GETPEERNAME		69
#define	SYS_GETSOCKOPT		70
#define	SYS_SETSOCKOPT		71
#define	SYS_SENDMSG			72
#define	SYS_RECVMSG			73
#define	SYS_GETITIMER		74
#define	SYS_SETITIMER		75
#define	SYS_CHMOD			76
#define	SYS_FCHMOD			77
#define	SYS_CHOWN			78
#define	SYS_FCHOW			79
#define	SYS_UTIMES			80
#define	SYS_TEST			81
#define	SYS_ENTRYS			82		/* ƥॳ륨ȥ꡼ */


#endif
